/**
 * Application
 */
import { FunctionComponent, useState, useRef } from 'react';
import { BryntumDemoHeader, BryntumThemeCombo, BryntumScheduler } from '@bryntum/schedulerpro-react';
import { ColumnConfig, SchedulerResourceModelConfig } from '@bryntum/schedulerpro';
import { schedulerConfig } from './AppConfig';
import './App.scss';

const App: FunctionComponent = () => {
    const schedulerRef = useRef<BryntumScheduler>(null);

    const [resources, setResources] = useState<Partial<SchedulerResourceModelConfig>[]>([
        {
            id: 'r1',
            name: 'Resource 1',
            children: [
                {
                    id: 'r11',
                    name: 'Starting Point',
                    level: 'E',
                    orderNum: 0,
                },
            ],
        },
    ]);

    const columns: Partial<ColumnConfig>[] = [{
        field: 'name',
        text: 'Name',
        type: 'tree',
        tree: true,
        hidden: false,
    }];

    return (
        <>
            {/* BryntumDemoHeader component is used for Bryntum example styling only and can be removed */}
            <BryntumDemoHeader
                children={<BryntumThemeCombo />}
            />
            <BryntumScheduler
                ref={schedulerRef}
                {...schedulerConfig}
                treeFeature={true}
                columns={columns}
                resources={resources}
                onScheduleClick={() => {
                    setResources([
                        {
                            id: 'r1',
                            name: 'Resource 1',
                            children: true,
                        }
                    ]);
                }

                }
            />
        </>
    );
};

export default App;
